#ifndef XNC_ACTIONS
#define XNC_ACTIONS

#define AMoveUp 1
#define AMoveDown 2
#define AMoveLeft 3
#define AMoveRight 4
#define AExecute 5
#define AInsert 6
#define AMan 7
#define AMenu 8
#define AFView 9
#define AFEdit 10
#define AFCopy 11
#define AFMove 12
#define AFDelete 13
#define ASwitchTab 14
#define ASwitchtoTerm 15
#define ARereadDir 16
#define AAttributes 17
#define AKill 18
#define AMakeDir 19
#define AInvertMask 20
#define ASelectMask 21
#define ADeselectMask 22
#define ACmdUp 23
#define ACmdDown 24
#define ACmdRight 25
#define ACmdLeft 26
#define ACmdLast 27
#define AFind 28
#define AQuickView 29
#define AMemory 30
#define AQuit 31
#define ABgExecute 32
#define APrint 33
#define ARaise 34
#define AFSimpleView 35
#define ARemountList 36
#define ARemount 37
#define AFNewEdit 38
#define ADiskInfo 39
#define ABookAdd 40
#define ABook1 41
#define ABook2 42
#define ABook3 43
#define ABook4 44
#define ABook5 45
#define ABook6 46
#define ABook7 47
#define ABook8 48
#define ABook9 49
#define ADelBook 50
#define AChown 51
#define ACleanCache 52
#define AFtpLink 53
#define AInsertLeftDir 54
#define AInsertRightDir 55
#define ASelectFileMask 56
#define ADeselectFileMask 57
#define AMoveHome 58
#define AMoveEnd 59
#define AMovePageDn 60
#define AMovePageUp 61
#define AInodeInfo 62
#define AQuickFInfo 63
#define AEmpty 64

#define Alt  250
#define Ctrl 251
#define Shift 252

#endif